Module commit

Module commit 

Modules

message
ref_iter

Structs

ExtraHeaders
An iterator over extra headers in owned and borrowed commits.
MessageRef
A parsed commit message that assumes a title separated from the body by two consecutive newlines.

Constants

SIGNATURE_FIELD_NAME
The well-known field name for signatures on SHA-1 commits.
SIGNATURE_FIELD_NAME_SHA256
The well-known field name for signatures on SHA-256 commits.

Functions

signature_field_name
Return the signature field name Git uses for hash_kind.