Module body

Module body 

Structs

MessageBlock
A raw message portion and the contiguous trailers following it.
MessageBlocks
An iterator over raw message portions and the contiguous trailers following each one.
TrailerRef
A trailer as parsed from the commit message body.
Trailers
An iterator over trailers as parsed from a commit message body.