MessageBlock

Struct MessageBlock 

pub struct MessageBlock<'a> {
    pub message: &'a BStr,
    /* private fields */
}
A raw message portion and the contiguous trailers following it.

Fields

message: &'a BStr

The message bytes, including their original whitespace and line endings.

Implementations

Source

impl<'a> MessageBlock<'a>

pub fn trailers(&self) -> Trailers<'a>

Return the continuously parseable trailers immediately following message.