Never

Struct Never 

pub struct Never;
An implementation of object access traits that stores nothing and finds nothing. Use Never::panic_on_access() to panic on object access instead.

Implementations

Source

impl Never

pub const fn panic_on_access() -> PanicAlways

Return an implementation that panics whenever an object access trait method is called. Useful for asserting that an operation does not access the object database.