pub struct TagRefIter<'a> { /* private fields */ }Expand description
Like TagRef, but as Iterator to support entirely allocation free parsing.
It’s particularly useful to dereference only the target chain.
Implementations
Sourceimpl<'a> TagRefIter<'a>
impl<'a> TagRefIter<'a>
Sourcepub fn from_bytes(data: &'a [u8], hash_kind: Kind) -> TagRefIter<'a> ⓘ
pub fn from_bytes(data: &'a [u8], hash_kind: Kind) -> TagRefIter<'a> ⓘ
Create a tag iterator from data, parsing hashes as object_hash.
Sourcepub fn signature(data: &'a [u8]) -> Option<(SignatureRef<'a>, SignedData<'a>)>
pub fn signature(data: &'a [u8]) -> Option<(SignatureRef<'a>, SignedData<'a>)>
Extract a signature and the exact original bytes it covers via (signature, data-without-signature).
data must be the complete, undecoded tag-object contents—the same byte slice that can be passed to
TagRefIter::from_bytes(), not only the tag message or armored signature. Keeping the original bytes intact is
necessary because signature verification covers their exact representation.
Sourcepub fn target_id(self) -> Result<ObjectId, Error>
pub fn target_id(self) -> Result<ObjectId, Error>
Returns the target id of this tag if it is the first function called and if there is no error in decoding the data.
Note that this method must only be called once or else will always return None while consuming a single token.
Errors are coerced into options, hiding whether there was an error or not. The caller should assume an error if they
call the method as intended. Such a squelched error cannot be recovered unless the objects data is retrieved and parsed again.
next().