Exists

Trait Exists 

pub trait Exists {
    // Required method
    fn exists(&self, id: &oid) -> bool;
}
Check if an object is present in an object store.

Required Methods

fn exists(&self, id: &oid) -> bool

Returns true if the object exists in the database.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<T> Exists for &T
where T: Exists,

Source

fn exists(&self, id: &oid) -> bool

Source

impl<T> Exists for Box<T>
where T: Exists,

Source

fn exists(&self, id: &oid) -> bool

Source

impl<T> Exists for Rc<T>
where T: Exists,

Source

fn exists(&self, id: &oid) -> bool

Source

impl<T> Exists for Arc<T>
where T: Exists,

Source

fn exists(&self, id: &oid) -> bool

Implementors