Skip to main contentModule tree
Source Expand description
- editor
- write
- Editor
- The state needed to apply edits instantly to in-memory trees.
- Entry
- An entry in a
Tree, similar to an entry in a directory. - EntryMode
- The mode of items storable in a tree, similar to the file mode on a unix file system.
- EntryRef
- An element of a
TreeRef.
- EntryKind
- A discretized version of ideal and valid values for entry modes.
- name_order
- Compare entry names according to Git’s canonical tree ordering.
- next_entry
- Advance a path lookup by matching the next path component against
tree.