Modules
Structs
- Extra
Headers - An iterator over extra headers in owned and borrowed commits.
- Message
Ref - A parsed commit message that assumes a title separated from the body by two consecutive newlines.
Constants
- SIGNATURE_
FIELD_ NAME - The well-known field name for signatures on SHA-1 commits.
- SIGNATURE_
FIELD_ NAME_ SHA256 - The well-known field name for signatures on SHA-256 commits.
Functions
- signature_
field_ name - Return the signature field name Git uses for
hash_kind.