Structs
- Message
Block - A raw message portion and the contiguous trailers following it.
- Message
Blocks - An iterator over raw message portions and the contiguous trailers following each one.
- Trailer
Ref - A trailer as parsed from the commit message body.
- Trailers
- An iterator over trailers as parsed from a commit message body.