Modules
Structs
- Editor
- The state needed to apply edits instantly to in-memory trees.
- Entry
- An entry in a
Tree, similar to an entry in a directory. - Entry
Mode - The mode of items storable in a tree, similar to the file mode on a unix file system.
- Entry
Ref - An element of a
TreeRef.
Enums
- Entry
Kind - A discretized version of ideal and valid values for entry modes.
Functions
- next_
entry - Advance a path lookup by matching the next path component against
tree.